Learn R Programming

shinyscreenshot (version 0.2.1)

shinyscreenshot-package: shinyscreenshot: Capture Screenshots of Entire Pages or Parts of Pages in 'Shiny'

Description

Capture screenshots in 'Shiny' applications. Screenshots can either be of the entire viewable page, or a specific section of the page. The captured image is automatically downloaded as a PNG image, or it can also be saved on the server. Powered by the 'html2canvas' JavaScript library.

Arguments

Author

Maintainer: Dean Attali daattali@gmail.com (ORCID)

Authors:

See Also